pub struct DefaultRawClient(pub Client<TlsMetricsService<HttpsConnector<ProxyConnectorService<TimeoutService<HttpConnector>>>>, RawBody>);Expand description
The default raw client implementation used by conjure_runtime.
This is currently implemented with hyper and rustls, but that is subject to change at any time.
Tuple Fields
0: Client<TlsMetricsService<HttpsConnector<ProxyConnectorService<TimeoutService<HttpConnector>>>>, RawBody>Trait Implementations
Sourceimpl Service<Request<RawBody>> for DefaultRawClient
impl Service<Request<RawBody>> for DefaultRawClient
Sourcetype Response = Response<DefaultRawBody>
type Response = Response<DefaultRawBody>
The response type returned by the service.
Sourcetype Error = DefaultRawError
type Error = DefaultRawError
The error type returned by the service.